==> mm24kresogen_1.2.0.tar.gz: mm24kresogen/man/mm24kresogenCHRLOC.Rd <==
\name{mm24kresogenCHRLOC}
\alias{mm24kresogenCHRLOC}
\title{Map Manufacturer IDs to Chromosomal Location}
\description{
  mm24kresogenCHRLOC is an R environment that maps manufacturer identifiers to the
  starting position of the gene. The position of a gene is
  measured as the number of base pairs.
}
\details{
  Each manufacturer identifier maps to a named vector of chromosomal locations,
  where the name indicates the chromosome. Due to inconsistencies that
  may exist at the time the environment was built, these vectors may
  contain more than one chromosome and/or location. If the chromosomal
  location is unknown, the vector will contain an \code{NA}.
  
  Chromosomal locations on both the sense and antisense strands are
  measured as the number of base pairs from the p (5' end of the sense
  strand) to q (3' end of the sense strand) arms. Chromosomal locations on the
  antisense strand have a leading "-" sign (e. g. -1234567). 

  Mappings were based on data provided by:

  Golden Path:\url{http://127.0.0.1/annbuilder/hgdownload.cse.ucsc.edu/goldenPath/currentGenomes//Mus_musculus/database/}. Built: No build info available.
  
  Package built Thu Sep 21 14:42:38 2006
}
\examples{
    # Covert to a list
    xx <- as.list(mm24kresogenCHRLOC)
    # Remove probe identifiers that do not map to any CHRLOC
    xx <- xx[!is.na(xx)]
    if(length(xx) > 0){
        # Gets the location for the first five probes
        xx[1:5]
        # Gets the first one
        xx[[1]]
    }
}
\keyword{datasets}

==> mm24kresogen_1.4.1.tar.gz: mm24kresogen/man/mm24kresogenCHRLOC.Rd <==
\name{mm24kresogenCHRLOC}
\alias{mm24kresogenCHRLOC}
\title{Map Manufacturer IDs to Chromosomal Location}
\description{
  mm24kresogenCHRLOC is an R environment that maps manufacturer identifiers to the
  starting position of the gene. The position of a gene is
  measured as the number of base pairs.
}
\details{
  Each manufacturer identifier maps to a named vector of chromosomal locations,
  where the name indicates the chromosome. Due to inconsistencies that
  may exist at the time the environment was built, these vectors may
  contain more than one chromosome and/or location. If the chromosomal
  location is unknown, the vector will contain an \code{NA}.
  
  Chromosomal locations on both the sense and antisense strands are
  measured as the number of base pairs from the p (5' end of the sense
  strand) to q (3' end of the sense strand) arms. Chromosomal locations on the
  antisense strand have a leading "-" sign (e. g. -1234567). 

  Mappings were based on data provided by:

  Golden Path:\\url{http://xserve.local/annbuilder/hgdownload.cse.ucsc.edu/goldenPath/currentGenomes//Mus\_musculus/database/}. Built: No build info available.
  
  Package built Wed Mar 28 10:57:35 2007
}
\examples{
    # Covert to a list
    xx <- as.list(mm24kresogenCHRLOC)
    # Remove probe identifiers that do not map to any CHRLOC
    xx <- xx[!is.na(xx)]
    if(length(xx) > 0){
        # Gets the location for the first five probes
        xx[1:5]
        # Gets the first one
        xx[[1]]
    }
}
\keyword{datasets}
